"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useTooltipAnalytics;
var _config = require("../config");
var _analytics = require("../analytics");
var _compat = require("preact/compat");
function useTooltipAnalytics(_ref) {
  let {
    analytics,
    analyticsLabelOverride,
    onAnalyticsEvent = (0, _config.config)().defaultAnalyticsFunction,
    ariaLabel,
    triggerAriaLabel
  } = _ref;
  const contentRef = (0, _compat.useRef)();
  function sendTooltipEvent() {
    if (analytics !== true && (!(0, _config.config)().tooltipSendsAnalytics || analytics === false)) {
      return;
    }

    // In the case where an icon is supplied there won't be any internal text of the tooltip trigger.
    // So, getAnalyticsContentFromRefs will return undefined. In that case, grab the aria label for the trigger.
    // In the case of webcomponents, we need to grab the triggerAriaLabel.
    const tooltipText = analyticsLabelOverride ?? (0, _analytics.getAnalyticsContentFromRefs)([contentRef]) ?? ariaLabel ?? triggerAriaLabel;
    return onAnalyticsEvent({
      event_name: 'tooltip_viewed',
      event_extension: _analytics.eventExtensionText,
      text: tooltipText
    });
  }
  return {
    contentRef,
    sendTooltipEvent
  };
}