import type * as React from 'react';
import { AnalyticsOverrideProps } from '../analytics';
export type AlertHeadingLevel = '1' | '2' | '3' | '4' | '5' | '6';
export type AlertRole = 'alert' | 'alertdialog' | 'region' | 'status';
export type AlertVariation = 'error' | 'warn' | 'success' | 'informational';
export type AlertWeight = 'lightweight';
export interface BaseAlertProps extends AnalyticsOverrideProps {
    /**
     * Access a reference to the `alert` `div` element
     */
    alertRef?: (...args: any[]) => any;
    /**
     * Sets the focus on Alert during the first mount
     */
    autoFocus?: boolean;
    /**
     * The alert's body content
     */
    children?: React.ReactNode;
    className?: string;
    /**
     * Text for the alert heading
     */
    heading?: React.ReactNode;
    /**
     * Optional id used to link the `aria-labelledby` attribute to the heading. If not provided, a unique id will be automatically generated and used.
     */
    headingId?: string;
    /**
     * Heading type to override default `<h2>`.
     */
    headingLevel?: AlertHeadingLevel;
    /**
     * Boolean to hide the `Alert` icon
     */
    hideIcon?: boolean;
    /**
     * A unique ID for this element. A unique ID will be generated if one isn't provided.
     */
    id?: string;
    /**
     * ARIA `role`, which determines the accessibility role of the alert.
     * If not explicitly provided, the role is dynamically assigned based on the `variation`:
     * - For `variation="error"`, `role="alert"`
     * - For `variation="success"`, `role="status"`
     * - For `variation="warn"`, `role="alert"`
     * - Otherwise, defaults to `role="region"`
     */
    role?: AlertRole;
    /**
     * A string corresponding to the `Alert` weight classes (`lightweight`)
     */
    weight?: AlertWeight;
    /**
     * A string corresponding to the `Alert` variation classes (`error`, `warn`, `success`)
     */
    variation?: Exclude<AlertVariation, 'informational'>;
}
export type AlertProps = BaseAlertProps & Omit<React.ComponentPropsWithRef<'div'>, keyof BaseAlertProps>;
/**
 * For information about how and when to use this component,
 * [refer to its full documentation page](https://design.cms.gov/components/alert/).
 */
export declare const Alert: {
    (props: AlertProps): import("react/jsx-runtime").JSX.Element;
    defaultProps: {
        headingLevel: string;
    };
};
export default Alert;
