import type * as React from 'react';
export type ReviewHeadingLevel = '1' | '2' | '3' | '4' | '5' | '6';
export interface ReviewProps {
    /**
     * `Review` component's body content.
     */
    children: React.ReactNode;
    className?: string;
    /**
     * Optional label to give screen readers longer, more descriptive text to
     * explain the context of an edit link.
     */
    editAriaLabel?: string;
    /**
     * An optional node in place of the edit link. If this defined, no edit link will be shown.
     */
    editContent?: React.ReactNode;
    /**
     * Href for the edit link. If this is undefined, no edit link will be shown.
     */
    editHref?: string;
    editText?: React.ReactNode;
    heading?: React.ReactNode;
    /**
     * Heading type to override default `<h3>`.
     */
    headingLevel?: ReviewHeadingLevel;
    /**
     * An optional function that is executed on edit link click. The event and
     * props.editHref value are passed to this function.
     */
    onEditClick?: (...args: any[]) => any;
}
/**
 * For information about how and when to use this component,
 * [refer to its full documentation page](https://design.cms.gov/components/review/).
 */
export declare const Review: {
    (props: ReviewProps): import("react/jsx-runtime").JSX.Element;
    defaultProps: {
        headingLevel: string;
    };
};
export default Review;
